==> php54-owncloud-8.0.4.tgz: share/owncloud/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Security & Setup Warnings" : "Drošības & iestatījumu brīdinājumi",
    "Cron" : "Cron",
    "Sharing" : "Dalīšanās",
    "Security" : "Drošība",
    "Email Server" : "E-pasta serveris",
    "Log" : "Žurnāls",
    "Authentication error" : "Autentifikācijas kļūda",
    "Your full name has been changed." : "Jūsu pilnais vārds tika mainīts.",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "Files decrypted successfully" : "Fails veiksmīgi atšifrēts",
    "Couldn't decrypt your files, please check your owncloud.log or ask your administrator" : "Nebija iespējams atšifrēt jūsu failus. Lūdzu pārbaudiet owncloud.log failu vai palūdziet to jūsu administratoram",
    "Couldn't decrypt your files, check your password and try again" : "Nebija iespējams atšifrētu jūsu failus, pārbaudiet jūsu paroli un mēģiniet vēlreiz",
    "Encryption keys deleted permanently" : "Šifrēšanas atslēgas pilnībā izdzēstas",
    "Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" : "Nebija iespējams pilnībā dzēst jūsu šifrēšanas atslēgas. Lūdzu pārbaudiet owncloud.log failu vai palūdziet to jūsu administratoram",
    "Couldn't remove app." : "Nebija iespējams atslēgt lietoni.",
    "Backups restored successfully" : "Rezerves kopijas veiksmīgi atjaunotas",
    "Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" : "Nebija iespējams atjaunot jūsu šifrēšanas atslēgas. Lūdzu pārbaudiet owncloud.log failu vai palūdziet to jūsu administratoram",
    "Language changed" : "Valoda tika nomainīta",
    "Invalid request" : "Nederīgs vaicājums",
    "Admins can't remove themself from the admin group" : "Administratori nevar izņemt paši sevi no administratoru grupas",
    "Unable to add user to group %s" : "Nevar pievienot lietotāju grupai %s",
    "Unable to remove user from group %s" : "Nevar izņemt lietotāju no grupas %s",
    "Couldn't update app." : "Nevarēja atjaunināt lietotni.",
    "Wrong password" : "Nepareiza parole",
    "No user supplied" : "Nav norādīts lietotājs",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Lūdzu ievadiet administratora atjaunošanas paroli, citādi visi lietotāja dati tiks zaudēti",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "Back-end doesn't support password change, but the users encryption key was successfully updated." : "Aizmugursistēma neatbalsta paroles maiņu, bet lietotāja šifrēšanas atslēga tika veiksmīgi atjaunota.",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Enabled" : "Pievienots",
    "Not enabled" : "Nav pievienots",
    "Recommended" : "Rekomendēts",
    "Group already exists." : "Grupa jau eksistē.",
    "Unable to add group." : "Nevar pievienot grupu.",
    "Unable to delete group." : "Nevar izdzēst grupu.",
    "Saved" : "Saglabāts",
    "test email settings" : "testēt e-pasta iestatījumus",
    "If you received this email, the settings seem to be correct." : "Ja jūs saņēmāt šo e-pastu, tad izskatās, ka iestatījum ir pareizi.",
    "A problem occurred while sending the email. Please revise your settings." : "Neizdevās nosūtīt e-pastu. Lūdzu pārskatiet savus iestatījumus.",
    "Email sent" : "Vēstule nosūtīta",
    "You need to set your user email before being able to send test emails." : "Nepieciešams norādīt sava lietotāja e-pasta adresi, lai nosūtīta testa e-pastus.",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "Unable to create user." : "Nevar izveidot lietotāju.",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Unable to delete user." : "Nevar izdzēst lietotāju.",
    "Forbidden" : "Pieeja liegta",
    "Invalid user" : "Nepareizs lietotājs",
    "Unable to change mail address" : "Nevar nomainīt e-pasta adresi",
    "Email saved" : "E-pasts tika saglabāts",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Vai esat pārliecināts, ka vēlaties pievienot \"{domain}\" kā uzticamu domēnu?",
    "Add trusted domain" : "Pievienot uzticamu domēnu",
    "Sending..." : "Sūta...",
    "All" : "Visi",
    "Please wait...." : "Lūdzu, uzgaidiet....",
    "Error while disabling app" : "Kļūda, atvienojot lietotni",
    "Disable" : "Deaktivēt",
    "Enable" : "Aktivēt",
    "Error while enabling app" : "Kļūda, pievienojot lietotni",
    "Updating...." : "Atjaunina....",
    "Error while updating app" : "Kļūda, atjauninot lietotni",
    "Updated" : "Atjaunināta",
    "Uninstalling ...." : "Atinstalē ....",
    "Error while uninstalling app" : "Kļūda, atinstalējot lietotni",
    "Uninstall" : "Atinstalēt",
    "Select a profile picture" : "Izvēlieties profila attēlu",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Valid until {date}" : "Valīds līdz {date}",
    "Delete" : "Dzēst",
    "Decrypting files... Please wait, this can take some time." : "Atšifrēju failus... Uzgaidiet tas var ilgt kādu laiku.",
    "Delete encryption keys permanently." : "Dzēst šifrēšanas atslēgas pilnībā",
    "Restore encryption keys." : "Atjaunot šifrēšanas atslēgas.",
    "Groups" : "Grupas",
    "Unable to delete {objName}" : "Nevar izdzēst {objName}",
    "Error creating group" : "Kļūda, veidojot grupu",
    "A valid group name must be provided" : "Jānorāda derīgs grupas nosaukums",
    "deleted {groupName}" : "grupa {groupName} dzēsta",
    "undo" : "atsaukt",
    "no group" : "neviena grupa",
    "never" : "nekad",
    "deleted {userName}" : "lietotājs {userName} dzēsts",
    "add group" : "pievienot grupu",
    "A valid username must be provided" : "Jānorāda derīgs lietotājvārds",
    "Error creating user" : "Kļūda, veidojot lietotāju",
    "A valid password must be provided" : "Jānorāda derīga parole",
    "A valid email must be provided" : "Jānorāda derīga e-pasta adrese",
    "__language_name__" : "__valodas_nosaukums__",
    "Personal Info" : "Personīgā informācija",
    "SSL root certificates" : "SSL saknes sertifikāti",
    "Encryption" : "Šifrēšana",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Viss (letālas problēmas, kļūdas, brīdinājumi, informatīvas ziņas, atkļūdošanas paziņojumi)",
    "Info, warnings, errors and fatal issues" : "Informatīvas ziņas, brīdinājumi, kļūdas un letālas problēmas",
    "Warnings, errors and fatal issues" : "Brīdinājumi, kļūdas un letālas problēmas",
    "Errors and fatal issues" : "Kļūdas un letālas problēmas",
    "Fatal issues only" : "Tikai letālas problēmas",
    "None" : "Nav",
    "Login" : "Ierakstīties",
    "Plain" : "vienkāršs teksts",
    "NT LAN Manager" : "NT LAN Pārvaldnieks",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "Security Warning" : "Brīdinājums par drošību",
    "Setup Warning" : "Iestatīšanas brīdinājums",
    "Module 'fileinfo' missing" : "Trūkst modulis “fileinfo”",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Trūkst PHP modulis “fileinfo”. Mēs iesakām to aktivēt, lai pēc iespējas labāk noteiktu mime tipus.",
    "Locale not working" : "Lokāle nestrādā",
    "Please double check the <a href='%s'>installation guides</a>." : "Lūdzu, vēlreiz pārbaudiet <a href='%s'>instalēšanas palīdzību</a>.",
    "Last cron was executed at %s." : "Pēdējo reizi Cron tika izpildīts %s.",
    "Last cron was executed at %s. This is more than an hour ago, something seems wrong." : "Pēdējo reizi Cron tika izpildīts %s. Tas ir vairāk kā pirms stundas, kaut kas nav kārtībā.",
    "Execute one task with each page loaded" : "Izpildīt vienu uzdevumu ar katru ielādēto lapu",
    "Allow apps to use the Share API" : "Ļauj lietotnēm izmantot koplietošanas API",
    "Allow users to share via link" : "Ļaut lietotājiem dalīties caur saitēm",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Expire after " : "Nederīga pēc",
    "days" : "dienas",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Enforce HTTPS" : "Uzspiest HTTPS",
    "Forces the clients to connect to %s via an encrypted connection." : "Uzspiest klientiem pieslēgties pie %s caur šifrētu savienojumu.",
    "Please connect to your %s via HTTPS to enable or disable the SSL enforcement." : "Lūdzu slēdzieties pie %s caur HTTPS lai iespējotu vai atspējotu SSL izpildīšanu",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Credentials" : "Akreditācijas dati",
    "Log level" : "Žurnāla līmenis",
    "More" : "Vairāk",
    "Less" : "Mazāk",
    "Version" : "Versija",
    "Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." : "Izstrādājusi<a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud kopiena</a>,<a href=\"https://github.com/owncloud\" target=\"_blank\">pirmkodu</a>kurš ir licencēts zem <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
    "More apps" : "Vairāk programmu",
    "by" : "līdz",
    "User Documentation" : "Lietotāja dokumentācija",
    "Administrator Documentation" : "Administratora dokumentācija",
    "Online Documentation" : "Tiešsaistes dokumentācija",
    "Forum" : "Forums",
    "Bugtracker" : "Kļūdu sekotājs",
    "Commercial Support" : "Komerciālais atbalsts",
    "Get the apps to sync your files" : "Saņem lietotnes, lai sinhronizētu savas datnes",
    "Desktop client" : "Darbvirsmas klients",
    "Android app" : "Android lietotne",
    "iOS app" : "iOS lietotne",
    "Show First Run Wizard again" : "Vēlreiz rādīt pirmās palaišanas vedni",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Jūs lietojat <strong>%s</strong> no pieejamajiem <strong>%s</strong>",
    "Password" : "Parole",
    "Your password was changed" : "Jūru parole tika nomainīta",
    "Unable to change your password" : "Nevar nomainīt jūsu paroli",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "Full Name" : "Pilns vārds",
    "Email" : "E-pasts",
    "Your email address" : "Jūsu e-pasta adrese",
    "Profile picture" : "Profila attēls",
    "Upload new" : "Ielādēt jaunu",
    "Select new from Files" : "Izvēlēties jaunu no Failiem",
    "Remove image" : "Novākt attēlu",
    "Cancel" : "Atcelt",
    "Language" : "Valoda",
    "Help translate" : "Palīdzi tulkot",
    "Import Root Certificate" : "Importēt saknes sertifikātus",
    "Log-in password" : "Pieslēgšanās parole",
    "Decrypt all Files" : "Atšifrēt visus failus",
    "Username" : "Lietotājvārds",
    "Create" : "Izveidot",
    "Admin Recovery Password" : "Administratora atgūšanas parole",
    "Enter the recovery password in order to recover the users files during password change" : "Ievadiet atgūšanas paroli, lai varētu atgūt lietotāja failus paroles maiņas laikā.",
    "Group" : "Grupa",
    "Default Quota" : "Apjoms pēc noklusējuma",
    "Unlimited" : "Neierobežota",
    "Other" : "Cits",
    "Quota" : "Apjoms",
    "set new password" : "iestatīt jaunu paroli",
    "Default" : "Noklusējuma"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "Dalīšanās",
    "External Storage" : "Ārējā krātuve",
    "Cron" : "Cron",
    "Log" : "Žurnāls",
    "Authentication error" : "Autentifikācijas kļūda",
    "Your full name has been changed." : "Jūsu pilnais vārds tika mainīts.",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "Couldn't remove app." : "Nebija iespējams atslēgt lietoni.",
    "Language changed" : "Valoda tika nomainīta",
    "Invalid request" : "Nederīgs vaicājums",
    "Admins can't remove themself from the admin group" : "Administratori nevar izņemt paši sevi no administratoru grupas",
    "Unable to add user to group %s" : "Nevar pievienot lietotāju grupai %s",
    "Unable to remove user from group %s" : "Nevar izņemt lietotāju no grupas %s",
    "Couldn't update app." : "Nevarēja atjaunināt lietotni.",
    "Wrong password" : "Nepareiza parole",
    "No user supplied" : "Nav norādīts lietotājs",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Lūdzu ievadiet administratora atjaunošanas paroli, citādi visi lietotāja dati tiks zaudēti",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Enabled" : "Pievienots",
    "Not enabled" : "Nav pievienots",
    "Group already exists." : "Grupa jau eksistē.",
    "Unable to add group." : "Nevar pievienot grupu.",
    "Unable to delete group." : "Nevar izdzēst grupu.",
    "Saved" : "Saglabāts",
    "test email settings" : "testēt e-pasta iestatījumus",
    "Email sent" : "Vēstule nosūtīta",
    "You need to set your user email before being able to send test emails." : "Nepieciešams norādīt sava lietotāja e-pasta adresi, lai nosūtīta testa e-pastus.",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "Unable to create user." : "Nevar izveidot lietotāju.",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Unable to delete user." : "Nevar izdzēst lietotāju.",
    "Forbidden" : "Pieeja liegta",
    "Invalid user" : "Nepareizs lietotājs",
    "Unable to change mail address" : "Nevar nomainīt e-pasta adresi",
    "Email saved" : "E-pasts tika saglabāts",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Vai esat pārliecināts, ka vēlaties pievienot \"{domain}\" kā uzticamu domēnu?",
    "Add trusted domain" : "Pievienot uzticamu domēnu",
    "Sending..." : "Sūta...",
    "All" : "Visi",
    "Please wait...." : "Lūdzu, uzgaidiet....",
    "Error while disabling app" : "Kļūda, atvienojot lietotni",
    "Disable" : "Deaktivēt",
    "Enable" : "Aktivēt",
    "Error while enabling app" : "Kļūda, pievienojot lietotni",
    "Updating...." : "Atjaunina....",
    "Error while updating app" : "Kļūda, atjauninot lietotni",
    "Updated" : "Atjaunināta",
    "Uninstalling ...." : "Atinstalē ....",
    "Error while uninstalling app" : "Kļūda, atinstalējot lietotni",
    "Uninstall" : "Atinstalēt",
    "Select a profile picture" : "Izvēlieties profila attēlu",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Valid until {date}" : "Valīds līdz {date}",
    "Delete" : "Dzēst",
    "Groups" : "Grupas",
    "Unable to delete {objName}" : "Nevar izdzēst {objName}",
    "Error creating group" : "Kļūda, veidojot grupu",
    "A valid group name must be provided" : "Jānorāda derīgs grupas nosaukums",
    "deleted {groupName}" : "grupa {groupName} dzēsta",
    "undo" : "atsaukt",
    "no group" : "neviena grupa",
    "never" : "nekad",
    "deleted {userName}" : "lietotājs {userName} dzēsts",
    "add group" : "pievienot grupu",
    "A valid username must be provided" : "Jānorāda derīgs lietotājvārds",
    "Error creating user" : "Kļūda, veidojot lietotāju",
    "A valid password must be provided" : "Jānorāda derīga parole",
    "A valid email must be provided" : "Jānorāda derīga e-pasta adrese",
    "__language_name__" : "__valodas_nosaukums__",
    "SSL root certificates" : "SSL saknes sertifikāti",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Viss (letālas problēmas, kļūdas, brīdinājumi, informatīvas ziņas, atkļūdošanas paziņojumi)",
    "Info, warnings, errors and fatal issues" : "Informatīvas ziņas, brīdinājumi, kļūdas un letālas problēmas",
    "Warnings, errors and fatal issues" : "Brīdinājumi, kļūdas un letālas problēmas",
    "Errors and fatal issues" : "Kļūdas un letālas problēmas",
    "Fatal issues only" : "Tikai letālas problēmas",
    "None" : "Nav",
    "Login" : "Ierakstīties",
    "Plain" : "vienkāršs teksts",
    "NT LAN Manager" : "NT LAN Pārvaldnieks",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Trūkst PHP modulis “fileinfo”. Mēs iesakām to aktivēt, lai pēc iespējas labāk noteiktu mime tipus.",
    "Allow apps to use the Share API" : "Ļauj lietotnēm izmantot koplietošanas API",
    "Allow users to share via link" : "Ļaut lietotājiem dalīties caur saitēm",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Expire after " : "Nederīga pēc",
    "days" : "dienas",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Execute one task with each page loaded" : "Izpildīt vienu uzdevumu ar katru ielādēto lapu",
    "Encryption" : "Šifrēšana",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Credentials" : "Akreditācijas dati",
    "Log level" : "Žurnāla līmenis",
    "More" : "Vairāk",
    "Less" : "Mazāk",
    "Version" : "Versija",
    "by" : "līdz",
    "User Documentation" : "Lietotāja dokumentācija",
    "Forum" : "Forums",
    "Get the apps to sync your files" : "Saņem lietotnes, lai sinhronizētu savas datnes",
    "Desktop client" : "Darbvirsmas klients",
    "Android app" : "Android lietotne",
    "iOS app" : "iOS lietotne",
    "Show First Run Wizard again" : "Vēlreiz rādīt pirmās palaišanas vedni",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Jūs lietojat <strong>%s</strong> no pieejamajiem <strong>%s</strong>",
    "Password" : "Parole",
    "Unable to change your password" : "Nevar nomainīt jūsu paroli",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "Email" : "E-pasts",
    "Your email address" : "Jūsu e-pasta adrese",
    "Profile picture" : "Profila attēls",
    "Upload new" : "Ielādēt jaunu",
    "Select new from Files" : "Izvēlēties jaunu no Failiem",
    "Remove image" : "Novākt attēlu",
    "Cancel" : "Atcelt",
    "Language" : "Valoda",
    "Help translate" : "Palīdzi tulkot",
    "Username" : "Lietotājvārds",
    "Create" : "Izveidot",
    "Admin Recovery Password" : "Administratora atgūšanas parole",
    "Enter the recovery password in order to recover the users files during password change" : "Ievadiet atgūšanas paroli, lai varētu atgūt lietotāja failus paroles maiņas laikā.",
    "Group" : "Grupa",
    "Default Quota" : "Apjoms pēc noklusējuma",
    "Unlimited" : "Neierobežota",
    "Other" : "Cits",
    "Full Name" : "Pilns vārds",
    "Quota" : "Apjoms",
    "set new password" : "iestatīt jaunu paroli",
    "Default" : "Noklusējuma"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
